@@ -6,7 +6,7 @@
 ############################################################################################################
 ####### BEGINNING OF DATA FOR THE MORPH.pm, RETRIEVE.pm, REPORT.pm AND Descenf.pm MODULES (TILL END) #######
 
-$mypath = "/home/luca/t" ;# path of the directory in which you are going to work
+$mypath = "/home/luca/te" ;# path of the directory in which you are going to work
 
 @sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7 ] ] );
 #@sweeps = ( [ [ 1 ] ] );
@@ -17,12 +17,12 @@ $mypath = "/home/luca/t" ;# path of the directory in which you are going to work
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 4, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 2, 5 => 1, 6 => 4, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
+@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 2, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 #@mediumiters = ( { 1 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
@@ -44,7 +44,7 @@ inactivatesim => "n",
 inactivateres => "n",
 incativateret => "n",
 actonexisting_models => { 1 => "y" },
-simtools => { 1 => "esp-r", 
+simtools => { 1 => "esp-r",
 #2 => "energyplus" 
 },
 #evalfile => "evalfile.pl",
@@ -53,6 +53,8 @@ simtools => { 1 => "esp-r",
 
 $fileconfig = "boxform.cfg"; # name of the configuration file of the model, which will reside in the "./cfg/" directory in your model's directory.
 
+$max_processes = 7;
+
 $simnetwork = "n"; # is there a mass/flow network? This information regards the simulation settings.
 $exeonfiles = "y";
 $preventsim = "n";
@@ -635,15 +637,7 @@ $vals{1}{7}{todos} =
 
 $vals{1}{7}{recalculateish} = [[ "y" ]]; 
 # recalculate the solar radiation? "y" or "n". This way the "ish" module is launched just at the end of a whole morphing operation, and not at every sub-operations composing it.
-$vals{1}{7}{use_modish} = 
-[
-[
-[ 1, "/zones/box.shd", 7 ]
-]
-];
-#$vals{1}{7}{export_toenergyplus} = [ [ "y", "sim", "retrieve", "milan.epw", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], 
-#[ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], 
-#[ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ] ];
+
 
 
 
@@ -1488,6 +1482,8 @@ $vals{1}{112}{shift_vertices} =
 # ]
 #### @applytype111 = ( ["vertices_shift", "file_name", "target_file_name", "zone_letter"]);
 
+
+
 $vals{1}{111}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
 # "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
@@ -1550,8 +1546,6 @@ $vals{1}{5}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASF
 
 
 
-
-
 #############################################################################################
 
 
