@@ -22,14 +22,14 @@ $mypath = "/home/luca/t" ;# path of the directory in which you are going to work
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 2, 5 => 1, 6 => 2, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
+@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 2, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 #@mediumiters = ( { 1 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
 $file = "t";  # the root model directory.
 
 %dowhat = ( # This variables tells to the program what to do.
-morph => "y", # create cases for simulation?
+morph => "n", # create cases for simulation?
 simulate => "y", # simulate AND retrieve? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 retrieve => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 report => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
@@ -44,7 +44,7 @@ inactivatesim => "n",
 inactivateres => "n",
 incativateret => "n",
 actonexisting_models => { 1 => "y" },
-simtools => { 1 => "esp-r", 7
+simtools => { 1 => "esp-r",
 #2 => "energyplus" 
 },
 #evalfile => "evalfile.pl",
